BioSimulators utils documentation
===========================================

Command-line application and high-level utilities for reading, writing, validating, and executing `COMBINE/OMEX format <https://combinearchive.org/>`_ files that contain descriptions of simulations in `Simulation Experiment Description Markup Language <https://sed-ml.org/>`_ (SED-ML) format with models in formats such as the `BioNetGen Language <https://bionetgen.org>`_ (BNGL) and the `Systems Biology Markup Language <http://sbml.org>`_ (SBML).

Contents
--------

.. toctree::
   :maxdepth: 2

   installation.rst
   Tutorials <https://tutorial.biosimulators.org/>
   API documentation <source/biosimulators_utils.rst>
   about.rst
   genindex.rst
